@@ -1,7 +1,7 @@
 package App::plstrace;
 
-our $DATE = '2014-06-24'; # DATE
-our $VERSION = '0.05'; # VERSION
+our $DATE = '2014-12-10'; # DATE
+our $VERSION = '0.06'; # VERSION
 
 1;
 # ABSTRACT: Trace Perl function calls
@@ -18,7 +18,7 @@ App::plstrace - Trace Perl function calls
 
 =head1 VERSION
 
-This document describes version 0.05 of App::plstrace (from Perl distribution App-plstrace), released on 2014-06-24.
+This document describes version 0.06 of App::plstrace (from Perl distribution App-plstrace), released on 2014-12-10.
 
 =head1 SYNOPSIS
 
@@ -30,7 +30,7 @@ Please visit the project's homepage at L<https://metacpan.org/release/App-plstra
 
 =head1 SOURCE
 
-Source repository is at L<https://github.com/sharyanto/perl-App-plstrace>.
+Source repository is at L<https://github.com/perlancar/perl-App-plstrace>.
 
 =head1 BUGS
 
@@ -42,11 +42,11 @@ feature.
 
 =head1 AUTHOR
 
-Steven Haryanto <stevenharyanto@gmail.com>
+perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Steven Haryanto.
+This software is copyright (c) 2014 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
